==> homesitemaker-v0.4.2.tar.gz: homesitemaker/includes/languages/catalan/homesite-info.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004 Marcos Martinez Jimenez

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/

//---------- ./homesite/info.php ----------

// Headline Row (HR)
$HR001="Editat per &uacute;ltima vegada: ";
$HR002="per";

// Info Botton
$IB001="Editar";
$IB002="Esborrar";

// Info Edition Messages (IEM)
$IEM001="Data dEdici&oacute;:";
$IEM002="Titular";
$IEM003="Text";
$TEXT008="Si envies com HTML, llavors les etiquetes s'interpretaran";
$TEXT009="Enviar com:";
$TEXT010="Text pla";
$TEXT011="HTML";

$IEM005="Aquesta es la llista actual de fotos per aquesta informaci&oacute;.<br>".
        "Pots seleccionar una o m&eacute;s per a que siguien esborrades.<br>".
        "Si desitges afegir un altre imatge a aquesta informaci&oacute;, ".
        "selecciona-la amb la opci&oacute; Adjuntar Foto.";

$IEM006="Adjuntar Foto:";

// Photo Table Editon Messages (PTEM)

$PTEM001="Esborrar";
$PTEM002="Nom d'arxiu";
$PTEM003="Id. Foto";
$PTEM004="Foto en miniatura";
 
// Info Edition Boton Messages (IEEBM)

$IEBM001="Previsualitzar";
$IEBM002="Publicar";  // See homesite-includes-dbwa.pnp before translate this

// Info Deleting Messages (IDM)

$IDM001="Data en que s'ha esborrat:";

$IDM002="Totes les dades es perdran i hi seran cambiades per ".
        "les opcions per defecte, si continues.<br><br>Asegura't abans de continuar !!!";

$IDM003="Si no desitjes mostrar mes aqueesta secci&oacute;, ".
        "hauras d'editar el fitxer de configuraci%oacute; de la web.";

// Info Deleting Boton Messages (IDBM)

$IDBM001="Esborrar";

// Info Edition Alert Messages

$ALERT001="Secci&oacute; Buida !<br>".
          "Ptser vulguis afegir informaci&oacute; aqu&iacute;.<br>".
          "Pel contrari, hauries d'eliminar aquesta secci&oacute;.";

?>

==> homesitemaker-v0.4.4.tar.gz: homesitemaker/includes/languages/catalan/homesite-info.php <==
<?php

/*
Home Site Maker, the websites factory.
Copyright (C) 2004 Marcos Martinez Jimenez

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

Marcos Martinez Jimenez
marcos@assl-site.net
http://homesitemaker.no-ip.org
Francesc Llunell n 1 4 5, Esplugues de Llobregat, 08950 Barcelona, Spain
*/

//---------- ./homesite/info.php ----------

// Headline Row (HR)
$HR001="Editat per &uacute;ltima vegada: ";
$HR002="per";

// Info Botton
$IB000="Editar (GUI)";
$IB001="Editar (texte)";
$IB002="Esborrar";

// Info Edition Messages (IEM)
$IEM001="Data dEdici&oacute;:";
$IEM002="Titular";
$IEM003="Text";
$TEXT008="Si envies com HTML, llavors les etiquetes s'interpretaran";
$TEXT009="Enviar com:";
$TEXT010="Text pla";
$TEXT011="HTML";
$TEXT012="Si no veus la barra d'Edici&ocaute;, es degut a que el teu navegador no suporta aquesta opci&oacute;.<br>".
         "Sellecciona la opci&oacute; 'Editar (texte)' o fes servir un d'aquets navegadors:<br>".
         "IE 5.5+ (Windows), Firefox 1.0+, Mozilla 1.3+ and Netscape 7+";

$IEM005="Aquesta es la llista actual de fotos per aquesta informaci&oacute;.<br>".
        "Pots seleccionar una o m&eacute;s per a que siguien esborrades.<br>".
        "Si desitges afegir un altre imatge a aquesta informaci&oacute;, ".
        "selecciona-la amb la opci&oacute; Adjuntar Foto.";

$IEM006="Adjuntar Foto:";

// Photo Table Editon Messages (PTEM)

$PTEM001="Esborrar";
$PTEM002="Nom d'arxiu";
$PTEM003="Id. Foto";
$PTEM004="Foto en miniatura";
 
// Info Edition Boton Messages (IEEBM)

$IEBM001="Previsualitzar";
$IEBM002="Publicar";  // See homesite-includes-dbwa.pnp before translate this

// Info Deleting Messages (IDM)

$IDM001="Data en que s'ha esborrat:";

$IDM002="Totes les dades es perdran i hi seran cambiades per ".
        "les opcions per defecte, si continues.<br><br>Asegura't abans de continuar !!!";

$IDM003="Si no desitjes mostrar mes aqueesta secci&oacute;, ".
        "hauras d'editar el fitxer de configuraci&oacute; de la web.";

// Info Deleting Boton Messages (IDBM)

$IDBM001="Esborrar";

// Info Edition Alert Messages

$ALERT001="Secci&oacute; Buida !<br>".
          "Ptser vulguis afegir informaci&oacute; aqu&iacute;.<br>".
          "Pel contrari, hauries d'eliminar aquesta secci&oacute;.";

?>
